<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="2.0" xmlns="http://www.w3.org/1999/xhtml"
                              xmlns:html="http://www.w3.org/1999/xhtml"
                              xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                              xmlns:wwdoc="urn:WebWorks-Document-Schema"
                              xmlns:wwproject="urn:WebWorks-Publish-Project"
                              xmlns:wwmode="urn:WebWorks-Engine-Mode"
                              xmlns:wwprojext="urn:WebWorks-XSLT-Extension-Project"
                              xmlns:wwfilesystem="urn:WebWorks-XSLT-Extension-FileSystem"
                              xmlns:wwuri="urn:WebWorks-XSLT-Extension-URI"
                              xmlns:wwimaging="urn:WebWorks-XSLT-Extension-Imaging"
                              xmlns:wwlog="urn:WebWorks-XSLT-Extension-Log"
                              xmlns:wwbehaviors="urn:WebWorks-Behaviors-Schema"
                              exclude-result-prefixes="xsl wwdoc wwproject wwmode wwprojext wwfilesystem wwlog wwbehaviors"
>

  <xsl:import href="wwtransform:super" />

  <xsl:template match="wwdoc:Table" mode="wwmode:content">
    <xsl:param name="ParamTable" select="." />
    <xsl:param name="ParamSplits" />
    <xsl:param name="ParamCargo" />
    <xsl:param name="ParamLinks" />
    <xsl:param name="ParamSplit" />
   

    <!-- Table Rule -->
    <!--            -->
    <xsl:variable name="VarOverrideRule" select="wwprojext:GetOverrideRule('Table', $ParamTable/@stylename, $ParamSplit/@documentID, $ParamTable/@id)" />
    <xsl:variable name="VarTableNoteImage" select="$VarOverrideRule/wwproject:Options/wwproject:Option[@Name = 'note-style-image'][1]" />

    <xsl:choose>
      <xsl:when test="(count($VarTableNoteImage) = 1) and (string-length($VarTableNoteImage/@Value) &gt; 0)">
   
        <html:table id="t_{$ParamTable/@id}" style="border: 0px; background-color: #aaa; padding: 0.5em; margin: 1em;">
          <html:tr style="vertical-align: top;">
     
            <xsl:variable name="VarImagePath" select="wwfilesystem:Combine(wwprojext:GetProjectFilesDirectoryPath(), $VarTableNoteImage/@Value)" />
            <xsl:variable name="VarImageInfo" select="wwimaging:GetInfo($VarImagePath)" />

            <!-- Image cell, first cell -->
            <!--                        -->
            <html:td style="width: {number($VarImageInfo/@width) + 10}px; text-align: center;">
              <html:div>
                <img id="img_{$ParamTable/@id}" src="{wwuri:GetRelativeTo($VarImagePath, $ParamSplit/@path)}" style="border: 0px;" />
              </html:div>
            </html:td>

            <!-- Second cell -->
            <!--             -->
            <html:td style="width: auto;">

              <xsl:apply-templates select="$ParamTable/wwdoc:TableBody/wwdoc:TableRow[1]/wwdoc:TableCell[2]/*" mode="wwmode:content">
                <xsl:with-param name="ParamSplits" select="$ParamSplits" />
                <xsl:with-param name="ParamCargo" select="$ParamCargo" />
                <xsl:with-param name="ParamLinks" select="$ParamLinks" />
                <xsl:with-param name="ParamTOCData" select="$GlobalFiles/wwmode:EmptySelection" />
                <xsl:with-param name="ParamSplit" select="$ParamSplit" />
              </xsl:apply-templates>
            </html:td>
          </html:tr>
        </html:table>
      </xsl:when>

      <xsl:otherwise>
        <xsl:for-each select="$ParamCargo/wwbehaviors:Behaviors[1]">
          <xsl:call-template name="Table">
            <xsl:with-param name="ParamSplits" select="$ParamSplits" />
            <xsl:with-param name="ParamCargo" select="$ParamCargo" />
            <xsl:with-param name="ParamLinks" select="$ParamLinks" />
            <xsl:with-param name="ParamTOCData" select="$GlobalFiles/wwmode:EmptySelection" />
            <xsl:with-param name="ParamSplit" select="$ParamSplit" />
            <xsl:with-param name="ParamTable" select="$ParamTable" />
            <xsl:with-param name="ParamOverrideRule" select="$VarOverrideRule" />
            <xsl:with-param name="ParamTableBehavior" select="key('wwbehaviors-tables-by-id', $ParamTable/@id)[1]" />
          </xsl:call-template>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>
</xsl:stylesheet>